CalendarStyleConfiguration class

Constructors

CalendarStyleConfiguration({Color? backgroundColor, Color? selectionColor, TextStyle? unselectedDateStyle, TextStyle? selectedDateStyle, TextStyle? yearTextStyle, TextStyle? monthTextStyle, TextStyle? dateTextStyle, ButtonStyleConfiguration? buttonStyleConfiguration})
const

Properties

backgroundColor → Color?
final
buttonStyleConfiguration → ButtonStyleConfiguration?
final
dateTextStyle → TextStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
monthTextStyle → TextStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedDateStyle → TextStyle?
final
selectionColor → Color?
final
unselectedDateStyle → TextStyle?
final
yearTextStyle → TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultStyle → CalendarStyleConfiguration
final